@@ -71,6 +71,7 @@ public:
 class FailedInsert : public Transactor
 {
   string m_Table;
+  static string LastReason;
 public:
   typedef RobustTransaction argument_type;
 
@@ -91,7 +92,12 @@ public:
 
   void OnAbort(const char Reason[]) throw ()
   {
-    cerr << "(Expected) Transactor " << Name() << " failed: " << Reason << endl;
+    if (Reason != LastReason)
+    {
+      cerr << "(Expected) Transactor " << Name() << " failed: " 
+	   << Reason << endl;
+      LastReason = Reason;
+    }
   }
 
   void OnCommit()
@@ -105,6 +111,7 @@ public:
   }
 };
 
+string FailedInsert::LastReason;
 
 } // namespace
 
